@@ -1,7 +1,7 @@
 # Basic MESI Write-back Invalidation Protocol
-from Protocol import Protocol
-from States import MESIState as State
-from Operations import MSIOps as Ops
+from .Protocol import Protocol
+from .States import MESIState as State
+from .Operations import MSIOps as Ops
 
 
 ###################
@@ -93,7 +93,6 @@ def example1():
     mesi.perform_instructions(instructions)
     mesi.print(_filter="transaction")
 
-
 ###################
 # Main
 ###################
