@@ -1,7 +1,10 @@
 from .cli import *
 from .hello import *
-from .Multiprocessor.MSI import MSI
-from .Multiprocessor.Operations import MSIOps as Ops
-from .Multiprocessor.Processor import Processor
+
 from .Multiprocessor.Protocol import Protocol
-from .Multiprocessor.States import MSIState as State
+from .Multiprocessor.VI_Write_Through import VI
+from .Multiprocessor.MSI import MSI
+from .Multiprocessor.MESI import MESI
+from .Multiprocessor.Processor import Processor
+from .Multiprocessor.Operations import MSIOps as Ops
+from .Multiprocessor.States import MESIState as State
